@@ -15,12 +15,13 @@
  *  WWW at http://www.gnu.org/copyleft/gpl.html).
  */
 
+
 #include <ctype.h>
 #include <sys/types.h>
 
 #include "globals.h"
 
-#include "endian.h"
+#include "cl_endian.h"
 #include "corpus.h"
 #include "macros.h"
 #include "fileutils.h"
@@ -331,7 +332,7 @@ setup_attribute(Corpus *corpus,
   attr = NULL;
 
   if (cl_new_attribute(corpus, attribute_name, type) != NULL)
-    fprintf(stderr, "attributes:setup_attribute(): Warning: \n"
+   Rprintf( "attributes:setup_attribute(): Warning: \n"
             "  Attribute %s of type %s already defined in corpus %s\n",
             attribute_name, aid_name(type), corpus->id);
   else {
@@ -422,7 +423,7 @@ cl_new_attribute_oldstyle(Corpus *corpus,
   attr = NULL;
 
   if (corpus == NULL)
-    fprintf(stderr, "attributes:find_attribute(): called with NULL corpus\n");
+   Rprintf( "attributes:find_attribute(): called with NULL corpus\n");
   else {
     
     for (attr = corpus->attributes; attr != NULL; attr = attr->any.next)
@@ -459,7 +460,7 @@ drop_attribute(Corpus *corpus,
                char *data)
 {
   if (corpus == NULL) {
-    fprintf(stderr, "attributes:drop_attribute(): called with NULL corpus\n");
+   Rprintf( "attributes:drop_attribute(): called with NULL corpus\n");
     return 0;
   }
   else
@@ -502,7 +503,7 @@ cl_delete_attribute(Attribute *attribute)
         ;
       
       if (prev == NULL)
-        fprintf(stderr, "attributes:cl_delete_attribute():\n"
+       Rprintf( "attributes:cl_delete_attribute():\n"
                 "  Warning: Attribute %s not in list of corpus attributes\n",
                 attribute->any.name);
       else {
@@ -582,7 +583,7 @@ declare_component(Attribute *attribute, ComponentID cid, char *path)
   Component *component;
 
   if (attribute == NULL) {
-    fprintf(stderr, "attributes:declare_component(): \n"
+   Rprintf( "attributes:declare_component(): \n"
             "  NULL attribute passed in declaration of %s component\n",
             cid_name(cid));
     return NULL;
@@ -608,7 +609,7 @@ declare_component(Attribute *attribute, ComponentID cid, char *path)
   }
   else {
 
-    fprintf(stderr, "attributes:declare_component(): Warning:\n"
+   Rprintf( "attributes:declare_component(): Warning:\n"
             "  Component %s of %s declared twice\n",
             cid_name(cid), attribute->any.name);
     return component;
@@ -634,7 +635,7 @@ declare_default_components(Attribute *attribute)
   int i;
 
   if (attribute == NULL)
-    fprintf(stderr, "attributes:declare_default_components(): \n"
+   Rprintf( "attributes:declare_default_components(): \n"
             "  NULL attribute passed -- can't create defaults\n");
   else {
     for (i = CompDirectory; i < CompLast; i++)
@@ -722,7 +723,7 @@ component_full_name(Attribute *attribute, ComponentID cid, char *path)
 {
   component_field_spec *compspec;
   Component *component;
-  
+
   static char buf[MAX_LINE_LENGTH];
   char rname[MAX_LINE_LENGTH];
   char *reference;
@@ -743,7 +744,7 @@ component_full_name(Attribute *attribute, ComponentID cid, char *path)
 
   if (path == NULL) {
     if ((compspec = find_cid_id(cid)) == NULL) {
-      fprintf(stderr, "attributes:component_full_name(): Warning:\n"
+     Rprintf( "attributes:component_full_name(): Warning:\n"
               "  can't find component table entry for Component #%d\n", cid);
       return NULL;
     }
@@ -791,7 +792,7 @@ component_full_name(Attribute *attribute, ComponentID cid, char *path)
         reference = component_full_name(attribute, compspec->id, NULL);
       
       if (reference == NULL) {
-        fprintf(stderr, "attributes:component_full_name(): Warning:\n"
+       Rprintf( "attributes:component_full_name(): Warning:\n"
                 "  Can't reference to the value of %s -- copying\n",
                 rname);
         reference = rname;
@@ -853,7 +854,7 @@ load_component(Attribute *attribute, ComponentID cid)
   comp = attribute->any.components[cid];
 
   if (comp == NULL) {
-    fprintf(stderr, "attributes:load_component(): Warning:\n"
+   Rprintf( "attributes:load_component(): Warning:\n"
             "  Component %s is not declared for %s attribute\n",
             cid_name(cid), aid_name(attribute->type));
   }
@@ -866,13 +867,13 @@ load_component(Attribute *attribute, ComponentID cid)
       if (item_sequence_is_compressed(attribute)) {
 
         if (read_file_into_blob(comp->path, MMAPPED, sizeof(int), &(comp->data)) == 0)
-          fprintf(stderr, "attributes:load_component(): Warning:\n"
+         Rprintf( "attributes:load_component(): Warning:\n"
                   "  Data of %s component of attribute %s can't be loaded\n",
                   cid_name(cid), attribute->any.name);
         else {
           
           if (attribute->pos.hc != NULL)
-            fprintf(stderr, "attributes:load_component: WARNING:\n\t"
+           Rprintf( "attributes:load_component: WARNING:\n\t"
                     "HCD block already loaded, overwritten.\n");
           
           attribute->pos.hc = new(HCD);
@@ -898,7 +899,7 @@ load_component(Attribute *attribute, ComponentID cid)
         }
       }
       else {
-        fprintf(stderr, "attributes/load_component: missing files of compressed PA,\n"
+       Rprintf( "attributes/load_component: missing files of compressed PA,\n"
                 "\tcomponent CompHuffCodes not loaded\n");
       }
 
@@ -907,7 +908,7 @@ load_component(Attribute *attribute, ComponentID cid)
       /* i.e. any ComponentID value except CompDirectory / CompLast and CompHuffCodes */
 
       if (read_file_into_blob(comp->path, MMAPPED, sizeof(int), &(comp->data)) == 0)
-        fprintf(stderr, "attributes:load_component(): Warning:\n"
+       Rprintf( "attributes:load_component(): Warning:\n"
                 "  Data of %s component of attribute %s can't be loaded\n",
                 cid_name(cid), attribute->any.name);
       else {
@@ -955,7 +956,7 @@ create_component(Attribute *attribute, ComponentID cid)
   Component *comp = attribute->any.components[cid];
   
   if (cl_debug) {
-    fprintf(stderr, "Creating %s\n", cid_name(cid));
+   Rprintf( "Creating %s\n", cid_name(cid));
   }
 
   if (component_state(attribute, cid) == ComponentDefined) {
@@ -974,7 +975,7 @@ create_component(Attribute *attribute, ComponentID cid)
     case CompCorpus:
     case CompLexicon:
     case CompLexiconIdx:
-      fprintf(stderr, "attributes:create_component(): Warning:\n"
+     Rprintf( "attributes:create_component(): Warning:\n"
               "  Can't create the '%s' component. Use 'encode' to create it"
               " out of a text file\n",
               cid_name(cid));
@@ -984,7 +985,7 @@ create_component(Attribute *attribute, ComponentID cid)
     case CompHuffSeq:
     case CompHuffCodes:
     case CompHuffSync:
-      fprintf(stderr, "attributes:create_component(): Warning:\n"
+     Rprintf( "attributes:create_component(): Warning:\n"
               "  Can't create the '%s' component. Use 'huffcode' to create it"
               " out of an item sequence file\n",
               cid_name(cid));
@@ -993,7 +994,7 @@ create_component(Attribute *attribute, ComponentID cid)
       
     case CompCompRF:
     case CompCompRFX:
-      fprintf(stderr, "attributes:create_component(): Warning:\n"
+     Rprintf( "attributes:create_component(): Warning:\n"
               "  Can't create the '%s' component. Use 'compress-rdx' to create it"
               " out of the reversed file index\n",
               cid_name(cid));
@@ -1021,7 +1022,7 @@ create_component(Attribute *attribute, ComponentID cid)
     case CompStrucData:
     case CompStrucAVS:
     case CompStrucAVX:
-      fprintf(stderr, "attributes:create_component(): Warning:\n"
+     Rprintf( "attributes:create_component(): Warning:\n"
               "  Can't create the '%s' component of %s attribute %s.\n"
               "  Use the appropriate external tool to create it.\n",
                cid_name(cid), aid_name(attribute->type), attribute->any.name);
@@ -1031,7 +1032,7 @@ create_component(Attribute *attribute, ComponentID cid)
 
     default:
       comp = NULL;
-      fprintf(stderr, "attributes:create_component(): Unknown cid: %d\n", cid);
+     Rprintf( "attributes:create_component(): Unknown cid: %d\n", cid);
       assert(0);
       break;
     }
@@ -1078,10 +1079,10 @@ ensure_component(Attribute *attribute, ComponentID cid, int try_creation)
   if ((comp = attribute->any.components[cid]) == NULL) {
 
     /*  component is undeclared */
-    fprintf(stderr, "attributes:ensure_component(): Warning:\n"
+   Rprintf( "attributes:ensure_component(): Warning:\n"
             "  Undeclared component: %s\n", cid_name(cid));
 #ifdef ENSURE_COMPONENT_EXITS    
-    exit(1);
+    rcqp_receive_error(1);
 #endif
     return NULL;
   }
@@ -1096,12 +1097,12 @@ ensure_component(Attribute *attribute, ComponentID cid, int try_creation)
       (void) load_component(attribute, cid); /* try to load the component */
       if (comp_component_state(comp) != ComponentLoaded) {
 #ifndef KEEP_SILENT
-        fprintf(stderr, "attributes:ensure_component(): Warning:\n"
+       Rprintf( "attributes:ensure_component(): Warning:\n"
                 "  Can't load %s component of %s\n", 
                 cid_name(cid), attribute->any.name);
 #endif
 #ifdef ENSURE_COMPONENT_EXITS    
-        exit(1);
+        rcqp_receive_error(1);
 #endif
         return NULL;
       }
@@ -1116,21 +1117,21 @@ ensure_component(Attribute *attribute, ComponentID cid, int try_creation)
         (void) create_component(attribute, cid);
         if (comp_component_state(comp) != ComponentLoaded) {
 #ifndef KEEP_SILENT
-          fprintf(stderr, "attributes:ensure_component(): Warning:\n"
+         Rprintf( "attributes:ensure_component(): Warning:\n"
                   "  Can't load or create %s component of %s\n", 
                   cid_name(cid), attribute->any.name);
 #endif
 #ifdef ENSURE_COMPONENT_EXITS
-          exit(1);
+          rcqp_receive_error(1);
 #endif
           return NULL;
         }
 #else
-        fprintf(stderr, "Sorry, but this program is not set up to allow the\n"
+       Rprintf( "Sorry, but this program is not set up to allow the\n"
                 "creation of corpus components. Please refer to the manuals\n"
                 "or use the ''makeall'' tool.\n");
 #ifdef ENSURE_COMPONENT_EXITS    
-        exit(1);
+        rcqp_receive_error(1);
 #endif
         return NULL;
 #endif
@@ -1138,32 +1139,32 @@ ensure_component(Attribute *attribute, ComponentID cid, int try_creation)
       }
       else {
 #ifndef KEEP_SILENT
-        fprintf(stderr, "attributes:ensure_component(): Warning:\n"
+       Rprintf( "attributes:ensure_component(): Warning:\n"
                 "  I'm not allowed to create %s component of %s\n", 
                   cid_name(cid), attribute->any.name);
 #endif
 #ifdef ENSURE_COMPONENT_EXITS    
-        exit(1);
+        rcqp_receive_error(1);
 #endif
         return NULL;
       }
       break;
 
     case ComponentUndefined:      /*  don't have this, -> error */
-      fprintf(stderr, "attributes:ensure_component(): Warning:\n"
+     Rprintf( "attributes:ensure_component(): Warning:\n"
               "  Can't ensure undefined/illegal %s component of %s\n", 
               cid_name(cid), attribute->any.name);
 #ifdef ENSURE_COMPONENT_EXITS    
-      exit(1);
+      rcqp_receive_error(1);
 #endif
       break;
 
     default:
-      fprintf(stderr, "attributes:ensure_component(): Warning:\n"
+     Rprintf( "attributes:ensure_component(): Warning:\n"
               "  Illegal state of  %s component of %s\n", 
               cid_name(cid), attribute->any.name);
 #ifdef ENSURE_COMPONENT_EXITS    
-      exit(1);
+      rcqp_receive_error(1);
 #endif
       break;
     }
@@ -1290,29 +1291,29 @@ describe_attribute(Attribute *attribute)
   DynArg *arg;
   ComponentID cid;
   
-  printf("Attribute %s:\n", attribute->any.name);
-  printf("  Type:        %s\n", aid_name(attribute->any.type));
+ Rprintf("Attribute %s:\n", attribute->any.name);
+ Rprintf("  Type:        %s\n", aid_name(attribute->any.type));
 
   /* print type dependent additional data */
 
   if (attribute->type == ATT_DYN) {
-    printf("  Arguments:   (");
+   Rprintf("  Arguments:   (");
     for (arg = attribute->dyn.arglist; arg; arg = arg->next) {
-      printf("%s", argid_name(arg->type));
+     Rprintf("%s", argid_name(arg->type));
       if (arg->next != NULL)
-        printf(", ");
+       Rprintf(", ");
     }
-    printf("):%s\n"
+   Rprintf("):%s\n"
            "               by \"%s\"\n",
            argid_name(attribute->dyn.res_type),
            attribute->dyn.call);
   }
-  printf("\n");
+ Rprintf("\n");
   for (cid = CompDirectory; cid < CompLast; cid++)
     if (attribute->any.components[cid])
       describe_component(attribute->any.components[cid]);
 
-  printf("\n\n");
+ Rprintf("\n\n");
 }
 
 /**
@@ -1321,29 +1322,29 @@ describe_attribute(Attribute *attribute)
 void
 describe_component(Component *component)
 {
-  printf("  Component %s:\n", cid_name(component->id));
-  printf("    Attribute:   %s\n", component->attribute->any.name);
-  printf("    Path/Value:  %s\n", component->path);
-  printf("    State:       ");
+ Rprintf("  Component %s:\n", cid_name(component->id));
+ Rprintf("    Attribute:   %s\n", component->attribute->any.name);
+ Rprintf("    Path/Value:  %s\n", component->path);
+ Rprintf("    State:       ");
 
   switch (comp_component_state(component)) {
   case ComponentLoaded: 
-    printf("loaded");
+   Rprintf("loaded");
     break;
   case ComponentUnloaded:
-    printf("unloaded (valid & on disk)");
+   Rprintf("unloaded (valid & on disk)");
     break;
   case ComponentDefined:
-    printf("defined  (valid, but not on disk)");
+   Rprintf("defined  (valid, but not on disk)");
     break;
   case ComponentUndefined:
-    printf("undefined (not valid)");
+   Rprintf("undefined (not valid)");
     break;
   default:
-    printf("ILLEGAL! (Illegal component state %d)", comp_component_state(component));
+   Rprintf("ILLEGAL! (Illegal component state %d)", comp_component_state(component));
     break;
   }
-  printf("\n\n");
+ Rprintf("\n\n");
 }
 
 
